@@ -1,10 +1,9 @@
-import json
 import logging
 from lxml import etree
 
 from bzt.jmx.base import JMX
 from bzt.jmx.tools import ProtocolHandler
-from bzt.utils import numeric_types, get_host_ips, simple_body_dict
+from bzt.utils import get_host_ips, convert_body_to_string
 
 LOG = logging.getLogger("")
 
@@ -35,7 +34,7 @@ class HTTPProtocolHandler(ProtocolHandler):
 
         content_encoding = scenario.get("content-encoding", None)
 
-        timeout = scenario.get("timeout", None)
+        timeout = scenario.get("timeout", "30s")
         timeout = self.safe_time(timeout)
         elements = [JMX._get_http_defaults(default_address, timeout, retrieve_resources,
                                            concurrent_pool_size, content_encoding, resources_regex),
@@ -43,16 +42,7 @@ class HTTPProtocolHandler(ProtocolHandler):
         return elements
 
     def get_sampler_pair(self, request):
-        timeout = self.safe_time(request.priority_option('timeout'))
-
-        # convert body to string
-        if isinstance(request.body, (dict, list, numeric_types)):
-            if request.get_header('content-type') == 'application/json' or isinstance(request.body, numeric_types):
-                request.body = json.dumps(request.body)
-            elif not simple_body_dict(request.body):
-                LOG.debug('Header "Content-Type: application/json" is required for body: "%s"', request.body)
-                request.body = json.dumps(request.body)
-
+        convert_body_to_string(request)
         use_random_host_ip = request.priority_option('random-source-ip', default=False)
         host_ips = get_host_ips(filter_loopbacks=True) if use_random_host_ip else []
 
@@ -64,6 +54,8 @@ class HTTPProtocolHandler(ProtocolHandler):
         if has_file_for_body and request.method != "GET":
             files = [{"path": body_file}]
 
+        timeout = self.safe_time(request.config.get("timeout"))
+
         http = JMX._get_http_request(request.url, request.label, request.method, timeout, request.body,
                                      request.priority_option('keepalive', default=True),
                                      files, request.content_encoding,
