@@ -33,10 +33,9 @@ from bzt import TaurusInternalException, TaurusConfigError, TaurusNetworkError
 from bzt.bza import User, Session, Test
 from bzt.engine import Reporter, Singletone
 from bzt.utils import b, humanize_bytes, iteritems, open_browser, BetterDict, to_json, dehumanize_time
-from bzt.modules.aggregator import AggregatorListener, DataPoint, KPISet, ResultsProvider
+from bzt.modules.aggregator import AggregatorListener, DataPoint, KPISet, ResultsProvider, ConsolidatingAggregator
 from bzt.modules.monitoring import Monitoring, MonitoringListener
 from bzt.modules.blazemeter.project_finder import ProjectFinder
-from bzt.modules.blazemeter.net_utils import send_with_retry
 from bzt.modules.blazemeter.const import NOTE_SIZE_LIMIT
 
 
@@ -76,6 +75,7 @@ class BlazeMeterUploader(Reporter, AggregatorListener, MonitoringListener, Singl
         Read options for uploading, check that they're sane
         """
         super(BlazeMeterUploader, self).prepare()
+
         self.send_interval = dehumanize_time(self.settings.get("send-interval", self.send_interval))
         self.send_monitoring = self.settings.get("send-monitoring", self.send_monitoring)
         monitoring_buffer_limit = self.settings.get("monitoring-buffer-limit", 500)
@@ -345,7 +345,6 @@ class BlazeMeterUploader(Reporter, AggregatorListener, MonitoringListener, Singl
                 self.__send_monitoring()
         return super(BlazeMeterUploader, self).check()
 
-    @send_with_retry
     def __send_data(self, data, do_check=True, is_final=False):
         """
         :type data: list[bzt.modules.aggregator.DataPoint]
@@ -353,7 +352,9 @@ class BlazeMeterUploader(Reporter, AggregatorListener, MonitoringListener, Singl
         if not self._session:
             return
 
+        self.engine.aggregator.converter(data)
         serialized = self._dpoint_serializer.get_kpi_body(data, is_final)
+
         self._session.send_kpi_data(serialized, do_check)
 
     def aggregated_second(self, data):
@@ -368,7 +369,6 @@ class BlazeMeterUploader(Reporter, AggregatorListener, MonitoringListener, Singl
         if self.send_monitoring:
             self.monitoring_buffer.record_data(data)
 
-    @send_with_retry
     def __send_monitoring(self):
         engine_id = self.engine.config.get('modules').get('shellexec').get('env').get('TAURUS_INDEX_ALL', '')
         if not engine_id:
@@ -539,7 +539,7 @@ class DatapointSerializer(object):
         # - elements of 'data' are described in __get_label()
         #
         # - elements of 'intervals' are described in __get_interval()
-        #   every interval contains info about response codes have gotten on it.
+        #   every interval contains info about response codes that were received on it.
         report_items = BetterDict()
         if data_buffer:
             self.owner.first_ts = min(self.owner.first_ts, data_buffer[0][DataPoint.TIMESTAMP])
@@ -590,7 +590,6 @@ class DatapointSerializer(object):
                     'failureMessage': error['msg'],
                     'name': error['tag'] if error['tag'] else 'All Assertions',
                     'failures': error['cnt']
-                    # TODO: "count", "errors" = ? (according do Udi's format description)
                 })
 
     def __get_label(self, name, cumul):
