@@ -17,9 +17,7 @@ limitations under the License.
 """
 import copy
 import csv
-import locale
 import os
-import sys
 import time
 from collections import Counter, OrderedDict
 from datetime import datetime
@@ -32,12 +30,7 @@ from bzt.modules.aggregator import DataPoint, KPISet, AggregatorListener, Result
 from bzt.modules.blazemeter import BlazeMeterUploader, CloudProvisioning
 from bzt.modules.functional import FunctionalAggregatorListener
 from bzt.modules.passfail import PassFailStatus
-from bzt.utils import etree, iteritems, get_full_path, is_windows
-
-if is_windows():
-    from terminaltables import AsciiTable as SingleTable
-else:
-    from terminaltables import SingleTable
+from bzt.utils import etree, iteritems, get_full_path
 
 
 class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
@@ -152,7 +145,6 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
             for case in self.cumulative_results.test_cases(test_suite):
                 status_counter[case.status] += 1
 
-        # FIXME: it's actually not tests, but test cases
         total = sum(count for _, count in iteritems(status_counter))
         self.log.info("Total: %s %s", total, self.__plural(total, 'test'))
 
@@ -175,8 +167,7 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
         data = [("Percentile, %", "Resp. Time, s")]
         for key in sorted(summary_kpi_set[KPISet.PERCENTILES].keys(), key=float):
             data.append((float(key), summary_kpi_set[KPISet.PERCENTILES][key]))
-            # self.log.info("Percentile %.1f%%: %.3f", )
-        table = SingleTable(data) if sys.stdout and sys.stdout.isatty() else AsciiTable(data)
+        table = AsciiTable(data)
         table.justify_columns[0] = 'right'
         table.justify_columns[1] = 'right'
         self.log.info("Percentiles:\n%s", table.table)
@@ -220,7 +211,7 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
         for sample_label in sorted_labels:
             if sample_label != "":
                 data.append(self.__get_sample_element(cumulative[sample_label], sample_label))
-        table = SingleTable(data) if sys.stdout and sys.stdout.isatty() else AsciiTable(data)
+        table = AsciiTable(data)
         table.justify_columns = justify
         self.log.info("Request label stats:\n%s", table.table)
 
@@ -298,9 +289,8 @@ class FinalStatus(Reporter, AggregatorListener, FunctionalAggregatorListener):
 
     def __dump_csv(self, filename):
         self.log.info("Dumping final status as CSV: %s", filename)
-        # FIXME: what if there's no last_sec
         with open(get_full_path(filename), 'wt') as fhd:
-            if '' in self.last_sec[DataPoint.CUMULATIVE]:
+            if self.last_sec and '' in self.last_sec[DataPoint.CUMULATIVE]:
                 fieldnames = self.__get_csv_dict('', self.last_sec[DataPoint.CUMULATIVE]['']).keys()
                 writer = csv.DictWriter(fhd, fieldnames)
                 writer.writeheader()
@@ -392,7 +382,7 @@ class JUnitXMLReporter(Reporter, AggregatorListener, FunctionalAggregatorListene
             self.process_functional(writer)
             writer.save_report(filename)
 
-        self.report_file_path = filename  # TODO: just for backward compatibility, remove later
+        self.report_file_path = filename
 
     def process_sample_labels(self, xunit):
         """
@@ -425,7 +415,7 @@ class JUnitXMLReporter(Reporter, AggregatorListener, FunctionalAggregatorListene
         :type xunit: XUnitFileWriter
         """
         xunit.report_test_suite('bzt_pass_fail')
-        mods = self.engine.reporters + self.engine.services  # TODO: remove it after passfail is only reporter
+        mods = self.engine.reporters
         pass_fail_objects = [_x for _x in mods if isinstance(_x, PassFailStatus)]
         self.log.debug("Processing passfail objects: %s", pass_fail_objects)
         fail_criteria = []
@@ -465,7 +455,6 @@ class JUnitXMLReporter(Reporter, AggregatorListener, FunctionalAggregatorListene
                 "skipped": str(len([sample for sample in samples if sample.status == "SKIPPED"])),
                 "failures": str(len([sample for sample in samples if sample.status == "FAILED"])),
                 "time": str(round(duration, 3)),
-                # TODO: "timestamp" attribute
             }
             xunit.add_test_suite(suite_name, attributes=attrs)
             for sample in samples:
